@@ -19,7 +19,7 @@ setwd("/tmp")                           # go to /tmp
 url <- "https://dailies.rstudio.com/rstudioserver/oss/bionic/x86_64/"
 pg <- read_html(url(url))
 tb <- html_table(html_nodes(pg, "table"))[[1]]
-file <- tb[1,1]
+file <- tb[[1,1]]
 s3url <- "https://s3.amazonaws.com/rstudio-ide-build/server/bionic/amd64/"
 fileurl <- paste0(s3url, file)
 download.file(fileurl, file, method="wget")
@@ -28,4 +28,3 @@ download.file(fileurl, file, method="wget")
 ## cf https://support.rstudio.com/hc/en-us/articles/203842428-Getting-the-newest-RStudio-builds
 ## fileurl <- "https://www.rstudio.org/download/latest/stable/server/ubuntu64/rstudio-server-latest-amd64.deb"
 #download.file(fileurl, "rstudio-server-latest-amd64.deb", method="wget")
-
